@@ -3,13 +3,16 @@ from typing import Union
 from disnake import Client
 from disnake.ext.commands import Bot
 
-__version__ = '1.0.10'
+from .cache import DocCache
+
+__version__ = '1.1.0'
 
 MAX_SIGNATURE_AMOUNT = 3
 PRIORITY_PACKAGES = (
     "python",
 )
 NAMESPACE = "doc"
+doc_cache = DocCache()
 
 
 def setup(bot: Union[Client, Bot]) -> None:
